@@ -2,7 +2,7 @@ import sysconfig
 # Category metadata.
 
 # Category icon show in the menu
-ICON = "icons/category.svg"
+ICON = "icons/logo.png"
 
 # Background color for category background in menu
 # and widget icon background in workflow.
